@@ -227,6 +227,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
                 "Axis dimensions other than 2 or 3 is not supported" "for set_labels."
             )
 
+    @rna.plotting.plot_signature
     def set_colorbar(
         self,
         axes,
@@ -446,7 +447,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         scale = kwargs.get("scale", 1.0)
 
         with self._prepared_figure(kwargs):
-            import matplotlib2tikz as tikz  # pylint: disable=
+            import matplotlib2tikz as tikz
 
             if width is None:
                 figurewidth = r"\textwidth"
@@ -596,6 +597,9 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             **kwargs: passed to PlotManager
         """
         x_index, y_index, z_index = self.pop_xyz_index(kwargs)
+        points = np.array(points)
+        if field is not None:
+            field = np.array(field)
 
         if field is not None and len(field.shape) == 2 and field.shape[1] == 1:
             # scalar
@@ -610,35 +614,44 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             color = kwargs.pop("color", field)
             artists = axes.scatter(*points, c=color, **kwargs)
         elif len(field.shape) == 2:
+            color = kwargs.get("color", None)
+            if rna.plotting.colors.color_fmt(color) == "norm":
+                kwargs.pop("color")
+                kwargs.setdefault("norm", mpl.colors.Normalize)
+                norm = kwargs.pop("norm")
+                if issubclass(norm, mpl.colors.Normalize):
+                    norm = norm(color.min(), color.max())
+                kwargs["norm"] = norm
+                args = (color,)
+            else:
+                kwargs.pop("norm", None)
+                args = tuple()
+
             # vector
             if points is None:
                 points = np.full(field.shape, 0.0)
-            artists = []
-            for point, vector in zip(points, field):
-                if self.axes_dim(axes) == 3:
-                    artists.append(
-                        axes.quiver(
-                            point[x_index],
-                            point[y_index],
-                            point[z_index],
-                            vector[x_index],
-                            vector[y_index],
-                            vector[z_index],
-                            **kwargs
-                        )
-                    )
-                elif self.axes_dim(axes) == 2:
-                    artists.append(
-                        axes.quiver(
-                            point[x_index],
-                            point[y_index],
-                            vector[x_index],
-                            vector[y_index],
-                            **kwargs
-                        )
-                    )
-                else:
-                    raise NotImplementedError("Dimension != 2|3")
+            if self.axes_dim(axes) == 3:
+                artists = axes.quiver(
+                    points[:, x_index],
+                    points[:, y_index],
+                    points[:, z_index],
+                    field[:, x_index],
+                    field[:, y_index],
+                    field[:, z_index],
+                    *args,
+                    **kwargs
+                )
+            elif self.axes_dim(axes) == 2:
+                artists = axes.quiver(
+                    points[:, x_index],
+                    points[:, y_index],
+                    field[:, x_index],
+                    field[:, y_index],
+                    *args,
+                    **kwargs
+                )
+            else:
+                raise NotImplementedError("Dimension != 2|3")
         else:
             raise NotImplementedError("Only Scalars and Vectors implemented")
         return artists
